@@ -1,12 +1,12 @@
 package Parse::Dia::SQL::Output::MySQL;
 
-# $Id: MySQL.pm,v 1.2 2009/02/24 05:45:22 aff Exp $
+# $Id: MySQL.pm,v 1.5 2009/03/02 13:41:39 aff Exp $
 
 =pod
 
 =head1 NAME 
 
-MySQL.pm - Base class for MySQL
+Parse::Dia::SQL::Output::MySQL - Create SQL for MySQL base class
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,7 @@ use Data::Dumper;
 use File::Spec::Functions qw(catfile);
 
 use lib q{lib};
-use base q{Parse::Dia::SQL::Output}; # extends
+use base q{Parse::Dia::SQL::Output};    # extends
 
 require Parse::Dia::SQL::Logger;
 require Parse::Dia::SQL::Const;
@@ -39,15 +39,14 @@ The constructor.
 =cut
 
 sub new {
-  my ( $class, %param ) = @_;
+  my ($class, %param) = @_;
   my $self = {};
 
   # Set defaults for MySQL (common for all storage engines)
   $param{object_name_max_length} = $param{object_name_max_length} || 64;
-  $param{db} = q{mysql};    
   $self = $class->SUPER::new(%param);
 
-  bless( $self, $class );
+  bless($self, $class);
   return $self;
 }
 
@@ -61,8 +60,14 @@ keep the interface consistent.
 =cut
 
 sub _get_drop_index_sql {
-  my ( $self, $tablename, $indexname ) = @_;
-  return qq{drop index $indexname on $tablename}
+  my ($self, $tablename, $indexname) = @_;
+
+  # Add backticks if option is set and dbtype is correct
+  $indexname = $self->_quote_identifier($indexname);
+  $tablename = $self->_quote_identifier($tablename);
+
+  return
+      qq{drop index $indexname on $tablename}
     . $self->{end_of_statement}
     . $self->{newline};
 }
@@ -79,28 +84,32 @@ sub get_schema_drop {
   my $self   = shift;
   my $sqlstr = '';
 
-	return unless $self->_check_classes();
+  return unless $self->_check_classes();
 
- CLASS:
+CLASS:
   foreach my $object (@{ $self->{classes} }) {
-		next CLASS if ($object->{type} ne q{table});
+    next CLASS if ($object->{type} ne q{table});
 
-		# Sanity checks on internal state
-		if (!defined($object) || ref($object) ne q{HASH} || !exists( $object->{name} )) {
-			$self->{log}->error( q{Error in table input - cannot create drop table sql!} );
-			next;
-		}
+    # Sanity checks on internal state
+    if (!defined($object)
+      || ref($object) ne q{HASH}
+      || !exists($object->{name}))
+    {
+      $self->{log}
+        ->error(q{Error in table input - cannot create drop table sql!});
+      next;
+    }
 
-		$sqlstr .= qq{drop table if exists }
-    . $object->{name}
-    . $self->{end_of_statement}
-    . $self->{newline};
+    $sqlstr .=
+        qq{drop table if exists }
+      . $self->_quote_identifier($object->{name})
+      . $self->{end_of_statement}
+      . $self->{newline};
   }
 
   return $sqlstr;
 }
 
-
 1;
 
 __END__
